Function block_identity
fn block_identity(node: &ExprUnsafe) -> StringExpand description
Stable identity for the body of an unsafe block. The expression tree keeps the operation’s semantic shape while discarding formatting and spans.
fn block_identity(node: &ExprUnsafe) -> StringStable identity for the body of an unsafe block. The expression tree keeps the operation’s semantic shape while discarding formatting and spans.