Function operation_drift
fn operation_drift(
index: usize,
expected: &Operation,
actual: Option<&ObservedOperation>,
) -> ErrorExpand description
The failure for a changed or missing operation identity or rationale.
fn operation_drift(
index: usize,
expected: &Operation,
actual: Option<&ObservedOperation>,
) -> ErrorThe failure for a changed or missing operation identity or rationale.