run

Function run 

pub fn run() -> Result<(), Vec<Error>>
Runs the check.

Errors

One Error::Unclassifiable per drifted lint, plus Error::Io if either manifest cannot be read and Error::Unclassifiable if either cannot be parsed or is missing a table this check is about.