run_one

Function run_one 

pub fn run_one(doc: &dyn GeneratedDoc, mode: Mode) -> Result<Outcome, Error>
Runs one generator under mode.

Errors

Error::Unclassifiable if the generator cannot read its source of truth, Error::Io if the page cannot be read or written, Error::Pragma if the page’s pragmas are missing or duplicated, and Error::Drift under Mode::Check if the page does not match.