item_kinds

Function item_kinds 

fn item_kinds(item: &Item) -> Vec<(String, Kind)>
The public names one item declares, with their kinds.

Usually one; a #[proc_macro_derive(Space, …)] pub fn derive_space declares a derive macro called Space, which is the name the facade re-exports and the name rustdoc files under derive.Space.html.