Function annotation_source
fn annotation_source(table: &TypeTable, surface: &ModuleSurface) -> StringExpand description
Collects the annotation text owned by one live module.
fn annotation_source(table: &TypeTable, surface: &ModuleSurface) -> StringCollects the annotation text owned by one live module.