Function module_imports
fn module_imports(
table: &TypeTable,
surface: &ModuleSurface,
prelude: &[String],
) -> Vec<String>Expand description
Renders only the candidate imports used by one module.
fn module_imports(
table: &TypeTable,
surface: &ModuleSurface,
prelude: &[String],
) -> Vec<String>Renders only the candidate imports used by one module.