Struct Member
pub(super) struct Member {
pub(super) name: String,
doc: Option<String>,
live_type_identity: Option<usize>,
pub(super) kind: MemberKind,
}Expand description
One member of a module or class.
Fields
name: StringThe attribute name.
doc: Option<String>Its docstring, if any.
live_type_identity: Option<usize>The identity of a live Python class object, when this member is one.
The pointer is used only while the embedded interpreter is attached: it is Python’s object identity, not a value that is rendered or persisted.
kind: MemberKindWhat kind of thing it is.