python_program

Function python_program 

fn python_program() -> OsString
The Python interpreter to drive the Python arms with.

PYTHON first so a caller can point the gate at the interpreter that has the wheel installed without activating anything.