Function implementors
fn implementors(
facade: &[SourceFile],
core: &[SourceFile],
) -> BTreeMap<String, BTreeSet<String>>Expand description
Every pub type in the two crates that implements one of the catalogued
traits, as trait name → type names.
A non-pub type is skipped: AlwaysPrune, CountingSampler and
BrokenStorage all implement these traits and are test doubles, not API.