Function default_closure
fn default_closure(features: &Table, default: &[String]) -> Vec<String>Expand description
Every feature of this crate that default turns on, transitively.
A dep:… or other-crate/feature member is not a feature of this crate and
is not part of the closure; it still appears in the “Enables” line, where it
belongs.