Function python_program
fn python_program() -> OsStringExpand description
The Python interpreter to drive the Python arms with.
PYTHON first so a caller can point the gate at the interpreter that has the
wheel installed without activating anything.